==> baiyx_mcp_server_dispatch-0.1.3-py3-none-any.whl: mcp_dispatch/mcp_dispatch_service.py <==
from mcp.server.fastmcp import FastMCP
from typing import List, Dict
import os
from .utils import Config
from .services import (
    get_pending_dispatch_details,
    find_records_by_order_numbers,
    check_dispatch_status,
    create_external_dispatch
)

# 创建MCP服务实例
mcp = FastMCP("dispatch-mcp-server", log_level="INFO")

def init_config(base_url: str, api_token: str, space_id: str):
    """初始化配置"""
    Config.init(base_url, api_token, space_id)

@mcp.tool(description="批量外部派车，支持多组订单号、供应商和指派类型")
async def batch_external_dispatch(dispatch_groups: List[Dict]) -> Dict:
    """批量外部派车
    
    Args:
        dispatch_groups: 派车组列表，每组包含：
            - order_numbers: 订单号列表
            - supplier_name: 供应商名称
            - dispatch_type: 派车类型
            
    Returns:
        Dict: 处理结果
    """
    success_count = 0
    failed_groups = []
    
    # 获取所有待指派明细
    success, all_records, error = get_pending_dispatch_details()
    if not success:
        return {
            "success": False,
            "message": f"获取待指派明细失败: {error}",
            "success_count": 0,
            "failed_groups": dispatch_groups
        }
    
    # 处理每组派车请求
    for group in dispatch_groups:
        try:
            order_numbers = group.get("order_numbers", [])
            supplier_name = group.get("supplier_name", "")
            dispatch_type = group.get("dispatch_type", "")
            
            # 参数验证
            if not order_numbers or not supplier_name or not dispatch_type:
                failed_groups.append({
                    **group,
                    "error": "参数不完整"
                })
                continue
            
            # 查找相关记录
            matched_records, dispatch_record_ids, missing_orders = find_records_by_order_numbers(
                all_records, order_numbers
            )
            
            # 检查是否所有订单都找到了
            if missing_orders:
                failed_groups.append({
                    **group,
                    "error": f"未找到订单: {', '.join(missing_orders)}"
                })
                continue
            
            # 检查是否已经派车给该供应商
            is_dispatched, error = check_dispatch_status(dispatch_record_ids, supplier_name)
            if is_dispatched:
                failed_groups.append({
                    **group,
                    "error": error
                })
                continue
            
            # 创建派车记录
            success, record_id, error = create_external_dispatch(
                supplier_name,
                dispatch_type,
                [record["recordId"] for record in matched_records]
            )
            
            if not success:
                failed_groups.append({
                    **group,
                    "error": error
                })
                continue
            
            success_count += 1
            
        except Exception as e:
            failed_groups.append({
                **group,
                "error": f"处理异常: {str(e)}"
            })
    
    return {
        "success": True,
        "message": "批量派车处理完成",
        "success_count": success_count,
        "failed_groups": failed_groups
    }

if __name__ == "__main__":
    # 启动MCP服务
    mcp.run(transport="stdio")

==> baiyx_mcp_server_dispatch-0.1.4-py3-none-any.whl: mcp_dispatch/mcp_dispatch_service.py <==
from mcp.server.fastmcp import FastMCP
from typing import List, Dict
import os
from .utils import Config
from .services import (
    get_pending_dispatch_details,
    find_records_by_order_numbers,
    check_dispatch_status,
    create_external_dispatch
)

# 创建MCP服务实例
mcp = FastMCP("dispatch-mcp-server", log_level="INFO")

def init_config(base_url: str, api_token: str, space_id: str):
    """初始化配置"""
    Config.init(base_url, api_token, space_id)

@mcp.tool(description="获取待指派的货物明细")
async def mcp_dispatch_get_pending_dispatch_details() -> Dict:
    """获取待指派的货物明细，支持分页查询所有记录
    
    Returns:
        Dict: {
            "success": bool,  # 是否成功
            "records": List[Dict],  # 记录列表
            "error": str  # 错误信息
        }
    """
    return await get_pending_dispatch_details()

@mcp.tool(description="批量外部派车，支持多组订单号、供应商和指派类型")
async def batch_external_dispatch(dispatch_groups: List[Dict]) -> Dict:
    """批量外部派车
    
    Args:
        dispatch_groups: 派车组列表，每组包含：
            - order_numbers: 订单号列表
            - supplier_name: 供应商名称
            - dispatch_type: 派车类型
            
    Returns:
        Dict: 处理结果
    """
    success_count = 0
    failed_groups = []
    
    # 获取所有待指派明细
    result = await get_pending_dispatch_details()
    success = result.get("success", False)
    all_records = result.get("records", [])
    error = result.get("error", "")
    
    if not success:
        return {
            "success": False,
            "message": f"获取待指派明细失败: {error}",
            "success_count": 0,
            "failed_groups": dispatch_groups
        }
    
    # 处理每组派车请求
    for group in dispatch_groups:
        try:
            order_numbers = group.get("order_numbers", [])
            supplier_name = group.get("supplier_name", "")
            dispatch_type = group.get("dispatch_type", "")
            
            # 参数验证
            if not order_numbers or not supplier_name or not dispatch_type:
                failed_groups.append({
                    **group,
                    "error": "参数不完整"
                })
                continue
            
            # 查找相关记录
            matched_records, dispatch_record_ids, missing_orders = find_records_by_order_numbers(
                all_records, order_numbers
            )
            
            # 检查是否所有订单都找到了
            if missing_orders:
                failed_groups.append({
                    **group,
                    "error": f"未找到订单: {', '.join(missing_orders)}"
                })
                continue
            
            # 检查是否已经派车给该供应商
            is_dispatched, error = check_dispatch_status(dispatch_record_ids, supplier_name, dispatch_type)
            if is_dispatched:
                failed_groups.append({
                    **group,
                    "error": error
                })
                continue
            
            # 创建派车记录
            success, record_id, error = create_external_dispatch(
                supplier_name,
                dispatch_type,
                [record["recordId"] for record in matched_records]
            )
            
            if not success:
                failed_groups.append({
                    **group,
                    "error": error
                })
                continue
            
            success_count += 1
            
        except Exception as e:
            failed_groups.append({
                **group,
                "error": f"处理异常: {str(e)}"
            })
    
    return {
        "success": True,
        "message": "批量派车处理完成",
        "success_count": success_count,
        "failed_groups": failed_groups
    }

if __name__ == "__main__":
    # 启动MCP服务
    mcp.run(transport="stdio")
